Struct EthernetDmaStorage
Source pub struct EthernetDmaStorage<const RX: usize, const TX: usize> { }
Available on crate feature unstable only.
Static backing storage for all DMA descriptor rings and packet buffers.
TX is the number of transmit slots; RX is the number of receive slots.
Pass a mutable reference to Ethernet::new.
Creates a zero-initialized storage block, suitable for static placement.
Returns the “default value” for a type.
Read more
Immutably borrows from an owned value.
Read more
Mutably borrows from an owned value.
Read more
Returns the argument unchanged.
Calls U::from(self).
That is, this conversion is whatever the implementation of
[From]<T> for U chooses to do.
The type returned in the event of a conversion error.
Performs the conversion.
The type returned in the event of a conversion error.
Performs the conversion.