RmiiClockConfig

Trait RmiiClockConfig 

pub trait RmiiClockConfig: Sealed {
    // Required method
    fn configure(self);
}
Sealed trait implemented by all RMII clock configurations.

Required Methods

fn configure(self)

Configures the hardware for RMII, including the clock input/output GPIO pad.

Consumes self so that the pin carried inside the struct is configured and ownership is transferred to the peripheral.

Dyn Compatibility

This trait is dyn compatible.

In older versions of Rust, dyn compatibility was called "object safety".

Implementors

Source

impl<P: RmiiClkIn> RmiiClockConfig for ExternalRefClock<P>

Available on crate feature unstable only.
Source

impl<POut: RmiiClkOut, PIn: RmiiClkIn> RmiiClockConfig for InternalRefClock<POut, PIn>

Available on crate feature unstable only.